##  Synchronizing a Project to an Existing Fact Sheet
You can sync an SAP Cloud ALM project to the fact sheet from which the synchronization setup was opened.
  1. In the synchronization setup overlay, select Link to an Existing Project in SAP Cloud ALM.
![Synchronizing a Project to an Existing Fact Sheet](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2755d3d67a4410149540993a0fce6bb2_LowRes.png)
Synchronizing a Project to an Existing Fact Sheet
  2. Select a project from the resulting drop-down list. The list shows all projects from the SAP Cloud ALM instance that you have configured.
  3. Click Start Syncing.


This action links the fact sheet to the SAP Cloud ALM project, syncing project data from SAP Cloud ALM to SAP LeanIX. In the agile tracking tab, you can view the project milestones and current phase (e.g., discover, realize, run). Additionally, project status, completion percentage, lifecycle status, and milestones are updated in the fact sheet fields.
